SET_CHARGE_PUMP = 141
SET_COL_ADDR = 33
SET_COM_OUT_DIR = 192
SET_COM_PIN_CFG = 218
SET_CONTRAST = 129
SET_DISP = 174
SET_DISP_CLK_DIV = 213
SET_DISP_OFFSET = 211
SET_DISP_START_LINE = 64
SET_ENTIRE_ON = 164
SET_MEM_ADDR = 32
SET_MUX_RATIO = 168
SET_NORM_INV = 166
SET_PAGE_ADDR = 34
SET_PRECHARGE = 217
SET_SEG_REMAP = 160
SET_VCOM_DESEL = 219

class SSD1306:
    ''
    def blit():
        pass

    def contrast():
        pass

    def fill():
        pass

    def fill_rect():
        pass

    def hline():
        pass

    def init_display():
        pass

    def invert():
        pass

    def line():
        pass

    def pixel():
        pass

    def poweroff():
        pass

    def poweron():
        pass

    def rect():
        pass

    def scroll():
        pass

    def show():
        pass

    def text():
        pass

    def vline():
        pass


class SSD1306_I2C:
    ''
    def blit():
        pass

    def contrast():
        pass

    def fill():
        pass

    def fill_rect():
        pass

    def hline():
        pass

    def init_display():
        pass

    def invert():
        pass

    def line():
        pass

    def pixel():
        pass

    def poweroff():
        pass

    def poweron():
        pass

    def rect():
        pass

    def scroll():
        pass

    def show():
        pass

    def text():
        pass

    def vline():
        pass

    def write_cmd():
        pass

    def write_data():
        pass


class SSD1306_SPI:
    ''
    def blit():
        pass

    def contrast():
        pass

    def fill():
        pass

    def fill_rect():
        pass

    def hline():
        pass

    def init_display():
        pass

    def invert():
        pass

    def line():
        pass

    def pixel():
        pass

    def poweroff():
        pass

    def poweron():
        pass

    def rect():
        pass

    def scroll():
        pass

    def show():
        pass

    def text():
        pass

    def vline():
        pass

    def write_cmd():
        pass

    def write_data():
        pass

def const():
    pass

framebuf = None
