AP_IF = 1
AUTH_OPEN = 0
AUTH_WEP = 1
AUTH_WPA2_PSK = 3
AUTH_WPA_PSK = 2
AUTH_WPA_WPA2_PSK = 4
MODE_11B = 1
MODE_11G = 2
MODE_11N = 3
STAT_CONNECTING = 1
STAT_CONNECT_FAIL = 4
STAT_GOT_IP = 5
STAT_IDLE = 0
STAT_NO_AP_FOUND = 3
STAT_WRONG_PASSWORD = 2
STA_IF = 0
def WLAN():
    pass

def phy_mode():
    pass

