
class CancelledError:
    ''
DEBUG = 0

class EventLoop:
    ''
    def call_at_():
        pass

    def call_later():
        pass

    def call_later_ms():
        pass

    def call_soon():
        pass

    def close():
        pass

    def create_task():
        pass

    def run_forever():
        pass

    def run_until_complete():
        pass

    def stop():
        pass

    def time():
        pass

    def wait():
        pass


class IORead:
    ''
    def handle():
        pass


class IOReadDone:
    ''
    def handle():
        pass


class IOWrite:
    ''
    def handle():
        pass


class IOWriteDone:
    ''
    def handle():
        pass


class PollEventLoop:
    ''
    def add_reader():
        pass

    def add_writer():
        pass

    def call_at_():
        pass

    def call_later():
        pass

    def call_later_ms():
        pass

    def call_soon():
        pass

    def close():
        pass

    def create_task():
        pass

    def remove_reader():
        pass

    def remove_writer():
        pass

    def run_forever():
        pass

    def run_until_complete():
        pass

    def stop():
        pass

    def time():
        pass

    def wait():
        pass


class SleepMs:
    ''
    def handle():
        pass


class StopLoop:
    ''
    def handle():
        pass


class StreamReader:
    ''
    aclose = None
    read = None
    readexactly = None
    readline = None

class StreamWriter:
    ''
    aclose = None
    awrite = None
    awriteiter = None
    def get_extra_info():
        pass


class SysCall:
    ''
    def handle():
        pass


class SysCall1:
    ''
    def handle():
        pass

def Task():
    pass


class TimeoutError:
    ''

class TimeoutObj:
    ''
_socket = None
def cancel():
    pass

core = None
def coroutine():
    pass

def ensure_future():
    pass

def get_event_loop():
    pass

log = None
open_connection = None
select = None
def set_debug():
    pass

sleep = None
sleep_ms = None
start_server = None
time = None

class type_gen:
    ''
    def close():
        pass

    def pend_throw():
        pass

    def send():
        pass

    def throw():
        pass

uasyncio = None
ucollections = None
uerrno = None
utimeq = None
def wait_for():
    pass

wait_for_ms = None
